#!/bin/bash
# How to use this script :
# 1    Create a directory EXP for your experiment ; ALL commands below must be run from EXP
# 2    Create a directory STORE to store the outputs of your experiment ; run "ln -s STORE storedir"
# 3    run "BASE/example.sh copy" where BASE is the directory containing this script
# 4a   (optional) Edit EXP/run_icosa.def to change nbp, dt, itau_physics
# 4b   (optional) Edit EXP/prepare.sh to change NB_MPI_DYNAMICO
# 4c   (optional) Edit EXP/example.sh to change ARCH, NB_YEARS
# 5    run "./example.sh create"
# 6    EXP run "./example.sh submit"

function fullpath() 
{ 
    echo "$(cd -P $1 ; pwd)"
}

function years()
{
    for ((i=$1;i<=$2;i++)) ; do
	echo $(printf 'year%02d' $i)
    done
}

function cmd_create()
{
    export ESM_ROOT=$(fullpath ESM_ROOT)
    STORE_ROOT=$( fullpath $PWD/storedir )
    YEARS=$(years 1 $NB_YEARS)
    for DIR in ce0l $YEARS ; do
	rm -rf $DIR $STORE_ROOT/$DIR
    done
    STORE0L="$STORE_ROOT/ce0l"
    $BASEDIR/prepare.sh ce0l ce0l "$STORE0L"
    $BASEDIR/prepare.sh first $STORE0L year01 "$STORE_ROOT/year01"
    PREV=year01
    for YEAR in $(years 2 $NB_YEARS) ; do
	$BASEDIR/prepare.sh next  $STORE0L "$STORE_ROOT/$PREV" $YEAR "$STORE_ROOT/$YEAR"
	PREV=$YEAR
    done
}

function submit_X64_CURIE()
{
    EXP=$1 ; shift
    CMD="ccc_msub $* $EXP/job.sh"
    MSG=$($CMD)
    echo "$CMD : $MSG"
    JOBID=$( echo "$MSG" | awk '{print $NF}' )
    DEP="-a $JOBID"
}

function cmd_submit()
{
    DEP=""
    submit_$ARCH ce0l
    for YEAR in $(years 1 $NB_YEARS) ; do
	submit_$ARCH $YEAR $DEP
    done
}

function cmd_copy()
{
    export ESM_ROOT=$( fullpath $BASEDIR/../../ )
    ln -sf $ESM_ROOT ESM_ROOT
    cp -fp $BASEDIR/*.sh $BASEDIR/*.xml $BASEDIR/*.def .
    ls -lrh
}

function cmd_()
{
echo
}

NB_YEARS=10
BASEDIR=$(dirname ${BASH_SOURCE[0]})
BASEDIR=$( fullpath $BASEDIR )
echo "Your command : $0 $*"
echo "Script base dir : $BASEDIR"
echo "Run from : $(fullpath $PWD)"
echo "Usage : $0 [copy|create|submit]"
export ARCH=X64_CURIE
cmd_$1
